@@ -19,7 +19,7 @@ J_LOG_NETWORK_DEBUG =128,  /* Networking debug */
 J_LOG_MENTOR_SPEECH =256  /* All what mentor tries to speak */
 };
 
-void cem_add_to_log(char *message,int type);
+void cem_add_to_log(const char* message, int type);
 void cem_set_log_level(int new_level);
 void cem_append_to_log_level(int level);
 void jammo_cem_cleanup();
