@@ -356,28 +356,27 @@ static ClutterActor* create_backing_track_color_bar(const gchar* color_coding, g
 
 
 static void on_cursor_notify_x(GObject* object, GParamSpec* param_spec, gpointer user_data) {
-	TangleVault* vault;
 	TangleScrollAction* scroll_action;
-	JammoCursor* cursor;
 	gfloat x, visible, offset, max;
 
-	vault = TANGLE_VAULT(user_data);
-	tangle_vault_get(vault, 2, TANGLE_TYPE_SCROLL_ACTION, &scroll_action, JAMMO_TYPE_CURSOR, &cursor);
+	scroll_action = user_data;
 	g_object_get(object, "x", &x, NULL);
 	g_object_get(scroll_action, "page-length-x", &visible, "offset-x", &offset, "max-offset-x", &max, NULL);
-	if (x < offset) {
+	gfloat old_offset = offset;
+
+	if (x < offset) { //Cursor is out of view somewhere too left
 		offset = x - visible + 80.0;
-		if (offset < 0.0) {
-			offset = 0.0;
-		}
-		tangle_object_animate(G_OBJECT(scroll_action), CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
-	} else if (x > offset + visible - 80.0) {
-		offset += 160.0;
-		if (offset > max) {
-			offset = max;
-		}
-		tangle_object_animate(G_OBJECT(scroll_action), CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
+	} else if (x > offset + visible - 80.0) { //Cursor is reaching right edge and there are need for scroll container
+		offset += 360.0;
 	}
+
+	//Check Min and Max boundaries:
+	if (offset < 0.0) offset = 0.0;
+	if (offset > max) offset = max;
+
+	//If there are no reason, do not do tangle_object_animate
+	if (offset != old_offset)
+		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
 }
 
 
@@ -906,10 +905,7 @@ if (use_two_tracks) y_offset=80;
 	clutter_container_add_actor(CLUTTER_CONTAINER(container_for_tracks), cursor);
 
 	ClutterAction* scroll_action = tangle_actor_get_action_by_type(container_for_tracks,TANGLE_TYPE_SCROLL_ACTION);
-	TangleVault* vault;
-
-	vault = tangle_vault_new(2, TANGLE_TYPE_SCROLL_ACTION, scroll_action, JAMMO_TYPE_CURSOR, cursor);
-	tangle_signal_connect_vault(texture, "notify::x", G_CALLBACK(on_cursor_notify_x), vault); //FIXME: this is not free'ed!
+	g_signal_connect(texture,  "notify::x", G_CALLBACK(on_cursor_notify_x), scroll_action);
 
 	//Each time start track scrolled begin.
 	g_object_set(scroll_action, "offset-x", 0, NULL);
