@@ -28,8 +28,8 @@ static gboolean tap_and_hold_function(gpointer user_data) {
 	g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(0));
 
 	const char* filename = clutter_actor_get_name(actor);
-	char* projects = configure_get_projects_directory();
-	char* finalized = configure_get_finalized_directory();
+	const char* projects = configure_get_projects_directory();
+	const char* finalized = configure_get_finalized_directory();
 	int type = -1;
 
 	if(strncmp(filename, projects, strlen(projects)) == 0){ // project
@@ -46,8 +46,8 @@ static gboolean tap_and_hold_function(gpointer user_data) {
 static void name_clicked(ClutterActor* actor) {
 
 	const char* filename = clutter_actor_get_name(actor);
-	char* projects = configure_get_projects_directory();
-	char* finalized = configure_get_finalized_directory();
+	const char* projects = configure_get_projects_directory();
+	const char* finalized = configure_get_finalized_directory();
 	int type = -1;
 
 	if(strncmp(filename, projects, strlen(projects)) == 0){ // project
@@ -145,13 +145,9 @@ void rename_loop(ClutterActor *loopName, int type){
 	
 		if(type == 0){
 
-			char *projects = configure_get_projects_directory();	
-			char new_projects_name[180] = ""; 
+			const char* projects = configure_get_projects_directory();
+			gchar* new_projects_name = g_strdup_printf("%s/%s.json",projects,givenname);
 
-			strcat(new_projects_name, projects);
-			strcat(new_projects_name, "/");
-			strcat(new_projects_name, givenname);
-			strcat(new_projects_name, ".json");
 
 			if(file_exist(path)){ //labelfile exists
 				newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
@@ -161,16 +157,11 @@ void rename_loop(ClutterActor *loopName, int type){
 			}
 			rename(filename, new_projects_name);
 			clutter_actor_set_name(loopName, new_projects_name);
-
+			g_free(new_projects_name);
 		}else if(type == 1){
 
-			char *finalized = configure_get_finalized_directory();	
-			char newname[180] = ""; 
-
-			strcat(newname, finalized);
-			strcat(newname, "/");
-			strcat(newname, givenname);
-			strcat(newname, ".ogg");
+			const char *finalized = configure_get_finalized_directory();
+			gchar* newname = g_strdup_printf("%s/%s.ogg",finalized,givenname);
 
 			if(file_exist(path)){ //labelfile exists
 				newpath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
@@ -180,6 +171,7 @@ void rename_loop(ClutterActor *loopName, int type){
 			}
 			rename(filename, newname);
 			clutter_actor_set_name(loopName, newname);
+			g_free(newname);
 		}
 		renaming_loop = FALSE;
 	}
