@@ -379,9 +379,9 @@ void level1_task3_on_act_redone(JammoGameTask* task, const gchar* task_name, gui
 	//In this task we want accept same act multiple times.
 	//we generate new act-name and add it to the list
 	// (using timestamp, so them will not collide)
-	char time[80];
-	cem_get_time(time);
-	gchar* name = g_strdup_printf("%s_%s",task_name,time);
+	char current_time[80];
+	cem_get_time(current_time);
+	gchar* name = g_strdup_printf("%s_%s",task_name,current_time);
 
 	jammo_game_task_add_act(task, name);
 	jammo_game_task_set_act_completed(task,name, TRUE);
@@ -529,9 +529,9 @@ void level1_task6_on_act_redone(JammoGameTask* task, const gchar* task_name, gui
 	//In this task we want accept same act multiple times.
 	//we generate new act-name and add it to the list
 	// (using timestamp, so them will not collide)
-	char time[80];
-	cem_get_time(time);
-	gchar* name = g_strdup_printf("%s_%s",task_name,time);
+	char current_time[80];
+	cem_get_time(current_time);
+	gchar* name = g_strdup_printf("%s_%s",task_name,current_time);
 
 	jammo_game_task_add_act(task, name);
 	jammo_game_task_set_act_completed(task,name, TRUE);
@@ -624,28 +624,28 @@ void level1_task7_started(JammoGameTask* task) {
 			free_slot[slot+3]=FALSE;
 	}
 
-	int index=-1;
+	int index_counter=-1;
 	int i;
 	for(i=0;i<8;i++) { //FIXME:use n_slots as max
 		if (free_slot[i]){
-			index=i;
+			index_counter=i;
 			break;
 			}
 	}
-	if (index==-1){ //means no free space
+	if (index_counter==-1){ //means no free space
 		//remove sample from slot 0
 		jammo_editing_track_view_remove_jammo_sample_button_from_slot(JAMMO_EDITING_TRACK_VIEW(track_view), 0);
-		index=0;
+		index_counter=0;
 	}
 
 	//Now we have guaranteed empty slot
-	jammo_editing_track_view_add_jammo_sample_button(JAMMO_EDITING_TRACK_VIEW(track_view), funny, index);
+	jammo_editing_track_view_add_jammo_sample_button(JAMMO_EDITING_TRACK_VIEW(track_view), funny, index_counter);
 
 	g_signal_connect(funny,"listened", G_CALLBACK(level1_task7_funny_listened),task);
 
 	//mentor blocks sight
 	float mentor_place=-240.0;
-	mentor_place+=50*index; //mentor_place= slot_index*width_of_slot * mentor_scale (75 * 1.5 = 50) //TODO: correct values
+	mentor_place+=50*index_counter; //mentor_place= slot_index*width_of_slot * mentor_scale (75 * 1.5 = 50) //TODO: correct values
 
 	//mentor: oops, I put funny sample to the track, listen it.
 	jammo_mentor_speak_and_highlight_with_callback(jammo_mentor_get_default(),
