@@ -833,8 +833,8 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 	return counter;
 }
 
-ClutterActor* sequencer_loop_get_nth_sample_looper(int index) {
-	switch (index) {
+ClutterActor* sequencer_loop_get_nth_sample_looper(int wheel_index) {
+	switch (wheel_index) {
 		case 1: return rhytmical_sample_looper;
 		case 2: return melodical_sample_looper;
 		case 3: return harmonical_sample_looper;
