@@ -82,6 +82,7 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 	}
 
 	cem_add_to_log("Pressed track label",J_LOG_USER_ACTION);
+	const gchar* name_of_track_view = clutter_actor_get_name(CLUTTER_ACTOR(track_view));
 	if (JAMMO_IS_MIDITRACK_VIEW(track_view))
 	{
 		cem_add_to_log("It is instrument track",J_LOG_USER_ACTION);
@@ -100,7 +101,6 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 	}
 	else if (JAMMO_IS_TRACK_VIEW(track_view))
 	{
-		const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(track_view));
 		//printf("It is slider track or backing-track\n");
 		TangleWidget* container2 = TANGLE_WIDGET(track_view);
 		JammoTrack* track;
@@ -111,13 +111,13 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 			instrument_gui_start(NULL, container2); //NULL means no keyboard, but slider
 		}
 		else if (JAMMO_IS_BACKING_TRACK(track)){
-			if (name && strcmp(name,"singing")==0)
+			if (name_of_track_view && strcmp(name_of_track_view,"singing")==0)
 				{
 				cem_add_to_log(" Singing track pressed",J_LOG_USER_ACTION);
 				clutter_actor_show(jammo_get_actor_by_id("singing-view"));
 				clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
 				}
-			else if (name && strcmp(name,"BackingTrack")==0)
+			else if (name_of_track_view && strcmp(name_of_track_view,"BackingTrack")==0)
 			{
 			cem_add_to_log(" Backing_track pressed",J_LOG_USER_ACTION);
 			clutter_actor_show(jammo_get_actor_by_id("backingtrack-selection-view"));
@@ -129,8 +129,7 @@ gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpoin
 	}
 	else if  (JAMMO_IS_EDITING_TRACK_VIEW(track_view)){
 			cem_add_to_log(" Editing_track pressed",J_LOG_USER_ACTION);
-			const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(track_view));
-			if (name && strcmp(name,"jammer")==0)
+			if (name_of_track_view && strcmp(name_of_track_view,"jammer")==0)
 				{
 				cem_add_to_log("  Jammer_track pressed",J_LOG_USER_ACTION);
 				tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
@@ -175,7 +174,7 @@ gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer dat
 	}
 
 	if (track_view==NULL) {
-		gchar* message = g_strdup_printf(" Not found track named '%s' for muting",name);
+		message = g_strdup_printf(" Not found track named '%s' for muting",name);
 		cem_add_to_log(message,J_LOG_FATAL);
 		g_free(message);
 		return FALSE;
@@ -310,7 +309,7 @@ gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer d
 	}
 
 	if (track_view==NULL) {
-		gchar* message = g_strdup_printf(" Not found track named '%s'",name);
+		message = g_strdup_printf(" Not found track named '%s'",name);
 		cem_add_to_log(message,J_LOG_FATAL);
 		g_free(message);
 		return FALSE;
@@ -354,31 +353,29 @@ gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer d
 
 //JSON callback
 void fullsequencer_on_cursor_notify_x(GObject* object, GParamSpec* param_spec, gpointer user_data) {
-	//printf("fullsequencer_on_cursor_notify_x\n");
-
-	ClutterActor* scrolling_view = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
-	ClutterAction* scroll_action = tangle_actor_get_action_by_type(scrolling_view,TANGLE_TYPE_SCROLL_ACTION);
-
+	ClutterAction* scroll_action;
 	gfloat x, visible, offset, max;
 
-	g_object_get(object, "x", &x, NULL);
-	g_object_get(scrolling_view, "width", &visible, NULL);
-	g_object_get(scroll_action, "offset-x", &offset, "max-offset-x", &max, NULL);
-	//printf("x=%f, visible-width =%f, offset=%f, max=%f\n",x,visible,offset,max);
+	ClutterActor* scrolling_view = jammo_get_actor_by_id("fullsequencer-container-for-tracks-outer");
+	scroll_action = tangle_actor_get_action_by_type(CLUTTER_ACTOR(scrolling_view),TANGLE_TYPE_SCROLL_ACTION);
 
-	if (x < offset) {
-		offset = x - visible + 80.0;
-		if (offset < 0.0) {
-			offset = 0.0;
-		}
-		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
-	} else if (x > offset + visible - 80.0) {
-		offset += 160.0;
-		if (offset > max) {
-			offset = max;
-		}
-		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
+	g_object_get(object, "x", &x, NULL);
+	g_object_get(scroll_action, "page-length-x", &visible, "offset-x", &offset, "max-offset-x", &max, NULL);
+	gfloat old_offset = offset;
+
+	if (x < offset) { //Cursor is out of view somewhere too left
+		offset = x - visible + 360.0;
+	} else if (x > offset + visible - 80.0) { //Cursor is reaching right edge and there are need for scroll container
+		offset += 360.0;
 	}
+
+	//Check Min and Max boundaries:
+	if (offset < 0.0) offset = 0.0;
+	if (offset > max) offset = max;
+
+	//If there are no reason, do not do tangle_object_animate
+	if (offset != old_offset)
+		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-x", offset, NULL);
 }
 
 /***************************
@@ -447,13 +444,26 @@ void sequencer_track_view_set_duration(guint64 duration) {
 	number_of_slots = n_slots;
 	duration_of_the_track = duration;
 
-	//CURSOR IS NOT USED
-	//CURSOR
-//	gfloat width_of_area = number_of_slots*width_of_slot;
-//	ClutterActor* cursor;
-//	cursor = jammo_get_actor_by_id("fullsequencer_cursor");
-//	if (cursor)
-//		clutter_actor_set_size(cursor, width_of_area, 80.0); //width is important, height is not used
+	//Set slot-duration for editing-track-views
+	//This is used when level is started from json.
+	ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
+
+	float slot_width;
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(container), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+		if (JAMMO_IS_EDITING_TRACK_VIEW(child)) {
+			g_object_set(child,"slot-duration",duration_of_one_slot,NULL);
+			g_object_set(child,"n-slots",number_of_slots,NULL);
+			g_object_get(child,"slot-width",&slot_width,NULL); //float
+		}
+	}
+
+	sequencer_track_view_fix_cursor();
+
+	//tune static variable
+	width_of_slot=slot_width;
+
 }
 
 
@@ -481,7 +491,6 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
        tangle_texture_new("/opt/jammo/sequencer/button_mute.png"), /* normal */
        tangle_texture_new("/opt/jammo/sequencer/button_mute_pressed.png"),  /* interactive */
        tangle_texture_new("/opt/jammo/sequencer/button_mute_pressed.png")); /* selected */
-	clutter_actor_set_size(mute_button, track_height-4,track_height-4); //it is square. Four pixels marginal
 	tangle_button_set_selected(TANGLE_BUTTON(mute_button),muted);
 
 	g_signal_connect(mute_button, "clicked", G_CALLBACK(pressed_sequencer_button_mute), track_view_actor);
@@ -511,8 +520,6 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
        volume_button_interactive,  /* interactive */
        volume_button_selected); /* selected */
 
-	clutter_actor_set_size(volume_button, track_height-4,track_height-4); //it is square. Four pixels marginal
-
 	g_signal_connect(volume_button, "clicked", G_CALLBACK(pressed_sequencer_button_volume), track_view_actor);
 	tangle_widget_add(TANGLE_WIDGET(panel_widget),volume_button,NULL);
 
@@ -539,22 +546,19 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
 
 ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, gint slot_width, const gchar* name_of_track_view) {
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
-	guint64 duration_of_tracks = duration_of_the_track; //this is static variable
-	//printf("Making editing track (duration: %" G_GUINT64_FORMAT ")\n", duration_of_tracks);
-
 	guint64 duration_of_one_slot;
 
 	if(number_of_slots == 0)
 		duration_of_one_slot = 0;
 	else	
-		duration_of_one_slot = duration_of_tracks / number_of_slots;
+		duration_of_one_slot = duration_of_the_track / number_of_slots; //these  are static variables
 		
 	ClutterActor *label;
 	const gchar* name_of_label_button;
 	JammoTrack* track;
 
 	//MEAM-track
-	track = JAMMO_TRACK(jammo_editing_track_new_fixed_duration(duration_of_tracks));
+	track = JAMMO_TRACK(jammo_editing_track_new());
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
 
 	if (slot_width==-1)
@@ -580,62 +584,82 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 	//Choose label-image and set color of track
 	ClutterColor sample_color =  { 0, 0, 0, 255 };
 	if (e_type == JAMMO_SAMPLE_RHYTMICAL) {
-		name_of_label_button = "/opt/jammo/sequencer/label_loop_rhythm.png";
+		name_of_label_button = "sequencer/label_loop_rhythm.png";
 		sample_color.red   = 255;
 		sample_color.green = 155;
 		sample_color.blue  = 0;
 	}
 	else if (e_type == JAMMO_SAMPLE_MELODICAL) {
-		name_of_label_button = "/opt/jammo/sequencer/label_loop_melody.png";
+		name_of_label_button = "sequencer/label_loop_melody.png";
 		sample_color.red   = 0;
 		sample_color.green = 0;
 		sample_color.blue  = 155;
 	}
 	else if (e_type == JAMMO_SAMPLE_HARMONICAL) {
-		name_of_label_button = "/opt/jammo/sequencer/label_loop_harmony.png";
+		name_of_label_button = "sequencer/label_loop_harmony.png";
 		sample_color.red   = 200;
 		sample_color.green = 0;
 		sample_color.blue  = 0;
 	}
 	else if (e_type == JAMMO_SAMPLE_EFFECT) {
-		name_of_label_button = "/opt/jammo/sequencer/label_loop_effect.png";
+		name_of_label_button = "sequencer/label_loop_effect.png";
 		sample_color.red    = 0;
 		sample_color.green  = 155;
 		sample_color.blue   = 0;
 	}
 	else {//Some sane default value
-		name_of_label_button = "/opt/jammo/sequencer/label_loop_effect.png";
+		name_of_label_button = "sequencer/label_loop_effect.png";
 		sample_color.alpha   = 0;
 	}
 
 	g_object_set(track_view_actor, "sample-color", &sample_color, NULL);
 
-	label = tangle_button_new_with_background_actors (
-       tangle_texture_new(name_of_label_button), /* normal */
-       tangle_texture_new(name_of_label_button));  /* interactive TODO*/
+	gchar* file_for_label_button = tangle_lookup_filename(name_of_label_button);
+	label = tangle_button_new_with_background_actor(tangle_texture_new(file_for_label_button));
+	g_free(file_for_label_button);
 	g_signal_connect(label, "clicked", G_CALLBACK(pressed_sequencer_button_track_label), track_view_actor);
 
 	create_control_panel_entry(track_view_actor, label, name_of_track_view, muted, volume);
 
+	//tune cursor
+	sequencer_track_view_fix_cursor();
+
+	//tune static variable
+	width_of_slot=slot_width;
 
 	return track_view_actor;
 }
 
+/*
+  This set width of the cursor (=width of the container it is moving)
+  and height of the cursor texture
+*/
+void sequencer_track_view_fix_cursor(){
+	TangleActorIterator actor_iterator;
+	TangleActorIterator actor_iterator2;
+	ClutterActor* child;
+	ClutterActor* child2;
+	ClutterActor*	container = jammo_get_actor_by_id("fullsequencer-container-for-tracks-outer");
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(container), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+		if (JAMMO_IS_CURSOR(child)) {
+			gfloat width_of_area = number_of_slots*width_of_slot;
+			clutter_actor_set_width(child, width_of_area); //width of cursor means total area for cursor to move
+			ClutterActor* texture_container=NULL;
+			g_object_get(child,"texture", &texture_container,NULL); //We know this cursor's texture is container
+			for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(texture_container), &actor_iterator2); (child2 = tangle_actor_iterator_get_actor(&actor_iterator2)); tangle_actor_iterator_next(&actor_iterator2)) {
+				if (CLUTTER_IS_RECTANGLE(child2)) { //This is the resizable part of the texture
+					clutter_actor_set_height(child2, clutter_actor_get_height(jammo_get_actor_by_id("fullsequencer-container-for-tracks"))-track_height);
+				}
+			}
+		}
+	}
+}
 
 ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat volume, const gchar* audio, const gchar* image, const gchar* name_of_track_view) {
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
-	guint64 duration_of_tracks = jammo_sequencer_get_duration(sequencer);
-
-	guint64 duration_of_one_slot;
-
-	if (number_of_slots == 0)
-		duration_of_one_slot = 0;
-	else
-		duration_of_one_slot = duration_of_tracks / number_of_slots;
-
 
 	ClutterActor *label;
-	const gchar* name_of_label_button;
+	gchar* name_of_label_button = tangle_lookup_filename("sequencer/label_backingtrack.png");
 	JammoTrack* track;
 	ClutterActor* track_view_actor;
 
@@ -657,11 +681,9 @@ ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat v
 	clutter_container_add_actor(CLUTTER_CONTAINER(container),track_view_actor);
 	clutter_actor_set_height(container,clutter_actor_get_height(container)+(float)track_height);
 
-	name_of_label_button = "/opt/jammo/sequencer/label_backingtrack.png";
 
-	label = tangle_button_new_with_background_actors (
-       tangle_texture_new(name_of_label_button), /* normal */
-       tangle_texture_new(name_of_label_button));  /* interactive TODO*/
+	label = tangle_button_new_with_background_actor(tangle_texture_new(name_of_label_button));
+	g_free(name_of_label_button);
 	g_signal_connect(label, "clicked", G_CALLBACK(pressed_sequencer_button_track_label), track_view_actor);
 
 
