@@ -319,13 +319,13 @@ void load_this_sample_array_to_this_track_view(JsonNode *sub_node,JammoEditingTr
 				sub_node = json_object_get_member (sample_object, "image");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
 					image_file =(gchar*)  json_node_get_string (sub_node);
-					printf("image: '%s'\n",image_file);
+					//printf("image: '%s'\n",image_file);
 				}
 				//string
 				sub_node = json_object_get_member (sample_object, "audio");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
 					audio_file =(gchar*)  json_node_get_string (sub_node);
-					printf("audio: '%s'\n",audio_file);
+					//printf("audio: '%s'\n",audio_file);
 				}
 
 				//int
@@ -421,7 +421,7 @@ This function returns list of all those folders (they all starts with SONGS_FOLD
 */
 GList *file_helper_get_all_songs() {
   GList *song_list = NULL;
-  gint index = 0;
+  gint index_counter = 0;
   gchar *song_name = NULL;
 
   GList *song_folders = scan_and_sort_directory( SONGS_DIR );
@@ -431,9 +431,9 @@ GList *file_helper_get_all_songs() {
       return NULL;
       }
 
-  for( index=0 ; index < g_list_length(song_folders) ; index++ )
+  for( index_counter=0 ; index_counter < g_list_length(song_folders) ; index_counter++ )
       {
-      gchar *element = (gchar *) g_list_nth_data( song_folders, index );
+      gchar *element = (gchar *) g_list_nth_data( song_folders, index_counter );
       song_name = g_strdup_printf("%s/%s", SONGS_DIR,element);
       song_list = g_list_append( song_list,song_name);
       //printf("added to list: '%s'\n",song_name);
@@ -443,7 +443,7 @@ GList *file_helper_get_all_songs() {
 
 GList *file_helper_get_all_files(const char* directory) {
   GList *song_list = NULL;
-  gint index = 0;
+  gint index_counter = 0;
   gchar *song_name = NULL;
 
   GList *song_folders = scan_and_sort_directory( directory );
@@ -455,9 +455,9 @@ GList *file_helper_get_all_files(const char* directory) {
       return NULL;
       }
 
-  for( index=0 ; index < g_list_length(song_folders) ; index++ )
+  for( index_counter=0 ; index_counter < g_list_length(song_folders) ; index_counter++ )
       {
-      gchar *element = (gchar *) g_list_nth_data( song_folders, index );
+      gchar *element = (gchar *) g_list_nth_data( song_folders, index_counter );
       song_name = g_strdup_printf("%s/%s", directory,element);
       song_list = g_list_append( song_list,song_name);
       //printf("added to list: '%s'\n",song_name);
@@ -468,7 +468,7 @@ GList *file_helper_get_all_files(const char* directory) {
 
 GList *file_helper_get_all_files_without_path(const char* directory) {
   GList *song_list = NULL;
-  gint index = 0;
+  gint index_counter = 0;
   gchar *song_name = NULL;
 
   GList *song_folders = scan_and_sort_directory( directory );
@@ -480,9 +480,9 @@ GList *file_helper_get_all_files_without_path(const char* directory) {
       return NULL;
       }
 
-  for( index=0 ; index < g_list_length(song_folders) ; index++ )
+  for( index_counter=0 ; index_counter < g_list_length(song_folders) ; index_counter++ )
       {
-      gchar *element = (gchar *) g_list_nth_data( song_folders, index );
+      gchar *element = (gchar *) g_list_nth_data( song_folders, index_counter );
       song_name = g_strdup_printf("%s",element);
       song_list = g_list_append( song_list,song_name);
       //printf("added to list: '%s'\n",song_name);
