@@ -152,6 +152,7 @@ void jammo_editing_track_view_add_jammo_sample_button(JammoEditingTrackView* tra
 
 /*
 Used when removing over network,
+Or when backingtrack changing causes clipping.
 */
 void jammo_editing_track_view_remove_jammo_sample_button_from_slot(JammoEditingTrackView* track_view, guint asked_slot) {
 	gfloat asked_x = asked_slot * track_view->priv->slot_width;
@@ -320,16 +321,12 @@ static void jammo_editing_track_view_constructed(GObject* object) {
 	g_signal_connect(drop_action, "dropped", G_CALLBACK(on_dropped), track_view);
 	clutter_actor_add_action(CLUTTER_ACTOR(track_view), drop_action);
 
-	g_object_set(track_view,"slot-duration",2653512050,NULL); //Fixme!
-
-	/* //Track is not ready yet?
+	/* //Checking number of slots and duration of slots on underlying editing-track
 	JammoEditingTrack* track=track_view->priv->track;
 	if (track) {
 		guint n_slots = track_view->priv->n_slots;
 		guint64 duration = jammo_editing_track_get_fixed_duration(track);
 		printf("n_slots %d, duration %llu\n",n_slots,duration);
-
-		g_object_set(track_view,"slot-duration",duration/n_slots);
 	}
 	*/
 }
@@ -491,7 +488,7 @@ static void jammo_editing_track_view_class_init(JammoEditingTrackViewClass* trac
 	                                "N slots",
 	                                "The number of slots",
 	                                0, G_MAXUINT, 0,
-	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
 	 * JammoEditingTrackView:slot-duration:
 	 *
