@@ -493,12 +493,12 @@ static void jammo_mentor_init(JammoMentor* mentor) {
 	}
 }
 
-static const gchar* find_characters(const gchar* string, const gchar* characters) {
+static const gchar* find_characters(const gchar* string, const gchar* characters_parameter) {
 	const gchar* found = NULL;
 	const gchar* c;
 	
 	while (!found && *string) {
-		for (c = characters; *c; c++) {
+		for (c = characters_parameter; *c; c++) {
 			if (*string == *c) {
 				found = string;
 				break;
@@ -510,12 +510,12 @@ static const gchar* find_characters(const gchar* string, const gchar* characters
 	return found;
 }
 
-static const gchar* find_characters_inverse(const gchar* string, const gchar* characters) {
+static const gchar* find_characters_inverse(const gchar* string, const gchar* characters_parameter) {
 	const gchar* found = NULL;
 	const gchar* c;
 	
 	while (*string) {
-		for (c = characters; *c; c++) {
+		for (c = characters_parameter; *c; c++) {
 			if (*string == *c) {
 				break;
 			}
