@@ -117,7 +117,7 @@ static TangleStylesheet* get_jammo_stylesheet(void) {
  * 	DATA_DIR
  * 	<current_working_directory>/data/jammo
  */
-static void add_search_paths(ClutterScript* script) {
+static void add_search_paths(ClutterScript* clutter_script) {
 	const gchar* default_search_path = DATA_DIR;
 	const gchar* default_search_path_audio = AUDIO_DIR;
 	gchar* development_search_path3_6;
@@ -133,7 +133,7 @@ static void add_search_paths(ClutterScript* script) {
 	search_paths[1] = development_search_path7_12;
 	search_paths[2] = default_search_path;
 	search_paths[3] = default_search_path_audio;
-	clutter_script_add_search_paths(script, search_paths, G_N_ELEMENTS(search_paths));
+	clutter_script_add_search_paths(clutter_script, search_paths, G_N_ELEMENTS(search_paths));
 
 	/* Remember to keep the paths above and below in sync! */
 	
@@ -428,10 +428,11 @@ int main(int argc, char** argv) {
 		tangle_stylesheet_set_default(stylesheet);
 	}
 
-	gchar* name_of_main_json = "jammo3_6.json";
+	const gchar* name_of_main_json;
 	if (!strcmp(application_name,"jammo7_12") || (argc>=2 && strcmp(argv[1],"sequencer")==0))
 			name_of_main_json="jammo7_12.json";
-
+	else
+		name_of_main_json = "jammo3_6.json";
 	//printf("looking id:main from file '%s'\n",name_of_main_json);
 
 	script = clutter_script_new();
