@@ -61,6 +61,11 @@ typedef enum
 #define CONNECTION_ERRORLIMIT 5
 // Basic interval for connection attempts, each error increases this by 1 second
 #define CONNECTION_INTERVAL 5.00
+// Idle limit for connecting devices (in jammo service verification phase)
+#define IDLE_CONNECTION_LIMIT 10.00
+// High and low for random connection delay
+#define AC_DELAY_HIGH 1.50
+#define AC_DELAY_LOW 0.10
 // Max size for group
 #define GROUP_MAX_SIZE 4
 // Group not assigned
