@@ -33,7 +33,7 @@ gint gems_service_jammo_process_connections()
 {	
 	gems_components* data = gems_get_data();
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE;
+	if(gems_get_peerhood() == NULL) return FALSE;
 	if(data->service_jammo->enabled == FALSE) return FALSE;
 	
 	data->service_jammo->connections = gems_service_jammo_process_list(data->service_jammo->connections, TRUE);
@@ -63,9 +63,19 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 			continue;
 		}
 		
-		if((ph_c_connection_is_connected(element->connection)) == TRUE && 
+		// Was idle for too long
+		if(gems_connection_get_last_action(element) > IDLE_CONNECTION_LIMIT)
+		{
+			cem_add_to_log("gems_service_jammo_process_connections: Disconnected a idle connection",J_LOG_NETWORK_DEBUG);
+			ph_c_connection_disconnect(element->connection);
+			cleanup_required = TRUE;
+		}
+		else if((ph_c_connection_is_connected(element->connection)) == TRUE && 
 			(ph_c_connection_has_data(element->connection) == TRUE))
-		{		
+		{	
+			// Something happened with this connection, set new time
+			gems_connection_set_action(element);	
+			
 			// Partial data
 			if(gems_connection_partial_data_amount(element) > 0)
 			{
@@ -301,6 +311,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 		
 		if(element->connection_state == JAMMO_CONNECTED_NO_AUTH)
 		{
+			gems_connection_clear_last_action(element);
 			tempiter = iterator; // temporary containing wanted data
 			iterator = g_list_next(iterator);
 		
@@ -315,6 +326,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 		// Versions do not match
 		else if(element->connection_state == JAMMO_VERSION_MISMATCH)
 		{
+			gems_connection_clear_last_action(element);
 			tempiter = iterator; // temporary containing wanted data
 			iterator = g_list_next(iterator);
 		
@@ -564,6 +576,8 @@ gboolean gems_service_jammo_process_error(gems_connection *element, gboolean ser
 					ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
+				gems_get_data()->connection_errorlist = gems_connection_error_add(gems_get_errorlist(),ph_c_connection_get_device_checksum(element->connection),ERROR_ALREADY_CONNECTED);
+				
 				success = FALSE; // remove this connection in gems_service_jammo_process_list
 				//data->connection_errorlist = gems_connection_error_add(data->connection_errorlist,ph_c_connection_get_device_checksum(element->connection), ERROR_ALREADY_CONNECTED);
 				break;
