@@ -21,7 +21,7 @@
 #include "gems_definitions.h"
 #include "ProfileManager.h"
 
-#define TO_FUNCTIONS 10
+#define TO_FUNCTIONS 11
 
 // States of connecting devices
 typedef enum {
@@ -179,6 +179,7 @@ typedef struct {
 	guint connection_errors;
 	gboolean version_mismatch;
 	gboolean already_connected;
+	gdouble already_connected_delay;
 	// TODO add "invalid messages" counter
 	GTimer* connection_timer;
 } gems_connection_error;
@@ -198,6 +199,7 @@ typedef struct {
 	
 	/* PeerHood */
 	MPeerHood* ph;
+	gboolean ph_on;
 	C_Callback* ph_cb;
 	
 	/* Initialized connections - gems_connection items*/
@@ -253,6 +255,7 @@ void gems_connection_clear_buffer(gems_connection* element);
 
 void gems_connection_set_action(gems_connection* element);
 double gems_connection_get_last_action(gems_connection* element);
+void gems_connection_clear_last_action(gems_connection* element);
 
 void gems_connection_add_16(gems_connection* element, guint16 value);
 void gems_connection_add_32(gems_connection* element, guint32 value);
