@@ -662,10 +662,10 @@ static gboolean gst_jammo_looper_stop (GstBaseSrc * basesrc)
 static gboolean gst_jammo_looper_do_seek (GstBaseSrc * basesrc, GstSegment * segment)
 {
   GstJammoLooper *src = GST_JAMMO_LOOPER (basesrc);
-  GstClockTime time;
+  GstClockTime time_to_seek;
 
   segment->time = segment->start;
-  time = segment->last_stop;
+  time_to_seek = segment->last_stop;
 
 	src->time = segment->time;
 	src->sample_index = 0;
@@ -697,16 +697,16 @@ static gboolean gst_jammo_looper_do_seek (GstBaseSrc * basesrc, GstSegment * seg
 
   /* now move to the time indicated */
   src->next_sample =
-      gst_util_uint64_scale_int (time, src->samplerate, GST_SECOND);
+      gst_util_uint64_scale_int (time_to_seek, src->samplerate, GST_SECOND);
   src->next_byte = src->next_sample * src->sample_size;
   src->next_time =
       gst_util_uint64_scale_int (src->next_sample, GST_SECOND, src->samplerate);
 
-  g_assert (src->next_time <= time);
+  g_assert (src->next_time <= time_to_seek);
 
   if (GST_CLOCK_TIME_IS_VALID (segment->stop)) {
-    time = segment->stop;
-    src->sample_stop = gst_util_uint64_scale_int (time, src->samplerate,
+    time_to_seek = segment->stop;
+    src->sample_stop = gst_util_uint64_scale_int (time_to_seek, src->samplerate,
         GST_SECOND);
     src->check_seek_stop = TRUE;
   } else {
@@ -878,10 +878,10 @@ static void gst_jammo_looper_set_property (GObject * object, guint prop_id,
 				// removes based on start time only
 				gint i;
 				LooperLoop * loop=NULL;
-				JammoLooperLoop * remove=g_value_get_pointer(value);
+				JammoLooperLoop* removed_loop=g_value_get_pointer(value);
 				for (i=0;i<g_list_length(src->loops);i++) {
 					loop = g_list_nth_data(src->loops, i);
-					if (loop->original_start==remove->start) {
+					if (loop->original_start==removed_loop->start) {
 						src->loops=g_list_remove(src->loops, loop);
 						if (loop->filename) {
 							g_free(loop->filename);
